def requestArgs(url,headers,params,proxies):
    args = {'url':url}
    if(bool(headers)):
        args.update({'headers' : headers})
    if(bool(params)):
        args.update({'params' : params})
    if(bool(proxies)):
        print("hi")
        args.update({'proxies' : proxies})
    return args


import requests
from bs4 import BeautifulSoup
from . import args

def get_rank(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    bojrank = soup.select_one("#statics > tbody > tr:nth-child(1) > td").text
    return bojrank

def get_correct_qs(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    correct_qs = soup.select_one("body > div.wrapper > div.container.content > div.row > div:nth-child(2) > div > div.col-md-9 > div:nth-child(2) > div.panel-body").text
    return correct_qs

def get_correct_q(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    correct_q = soup.select_one("#u-solved").text
    return correct_q

def get_unsolved_qs(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    wrong_qs = soup.select_one("body > div.wrapper > div.container.content > div.row > div:nth-child(2) > div.row > div.col-md-9 > div:nth-child(3) > div.panel-body").text
    return wrong_qs

def get_unsolved_q(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    wrong_q = soup.select_one("#u-failed").text
    return wrong_q

def get_submissions(user_name, headers={}, params={}, proxies={}):
    url = 'https://www.acmicpc.net/user/' + user_name
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, 'html.parser')
    submit_time = soup.select_one("#statics > tbody > tr:nth-child(4) > td > a").text
    return submit_time




import requests
from bs4 import BeautifulSoup
import random
from . import args

def get_question(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    question = soup.select_one("#problem_description > p")
    return question.text

def get_input(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    input = soup.select_one("#problem_input > p")
    return input.text

def get_output(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    output = soup.select_one("#problem_output > p")
    return output.text

def get_sample_input(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    sample_input = soup.select_one("#sample-input-1")
    return sample_input.text

def get_sample_output(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    sample_output = soup.select_one("#sample-output-1")
    return sample_output.text

def get_correct_rate(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    correct_rate = soup.select_one("#problem-info > tbody > tr > td:nth-child(6)")
    return correct_rate.text

def get_time_limit(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    time_cut = soup.select_one("#problem-info > tbody > tr > td:nth-child(1)")
    return time_cut.text

def get_memory_limit(number, headers={}, params={}, proxies={}):
    url = "https://www.acmicpc.net/problem/" + str(number)
    response = requests.get(**args.requestArgs(url,headers,params,proxies))
    soup = BeautifulSoup(response.text, "html.parser")
    memory_cut = soup.select_one("#problem-info > tbody > tr > td:nth-child(2)")
    return memory_cut.text

def get_random_question():
    url = "https://www.acmicpc.net/problem/" + str(random.randint(1000, 28677))
    return url




from setuptools import setup, find_packages
from os import path


setup(name='baekjoon-scraper', # 패키지 명

version='1.0.2',

description='A fork of smartwe\'s baekjoon api with optional argument fields for avoiding scraping detection' ,

long_description='An unofficial API for Baekjoon Online Judge that retrieves the data by scraping. This is a fork of smartwe\'s baekjoon package with additional parameters to the APIs in order to help bypass Baekjoon\'s bot detection while scraping. Read more at https://github.com/RoelYoon/baekjoon-scraper-api.git to learn how to use this package.',

author='RoelYoon',

author_email='roelyoon2@gmail.com',

url='https://github.com/RoelYoon/baekjoon-scraper-api.git',

license='MIT', # MIT에서 정한 표준 라이센스 따른다

py_modules=[''], # 패키지에 포함되는 모듈

python_requires='>=3',

install_requires=['bs4','requests'], # 패키지 사용을 위해 필요한 추가 설치 패키지

packages=['baekjoon'], # 패키지가 들어있는 폴더들

)